@@ -22,7 +22,9 @@
 
 #include "SettingsPage.h"
 
+class QButtonGroup;
 class QCheckBox;
+class QRadioButton;
 
 class GeneralOptionsPage : public SettingsPage
 {
@@ -30,22 +32,27 @@ class GeneralOptionsPage : public SettingsPage
 
     public:
 
-    explicit GeneralOptionsPage(QWidget *parent = 0);
+    explicit GeneralOptionsPage(QWidget *parent = nullptr);
 
-    public slots:
+    public Q_SLOTS:
 
-    void saveChanges() Q_DECL_OVERRIDE;
-    void resetChanges() Q_DECL_OVERRIDE;
+    void saveChanges() override;
+    void resetChanges() override;
 
-    private slots:
+    private Q_SLOTS:
 
-    void markDirty(bool checked);
+    void markDirty();
 
     private:
 
-    QCheckBox *mRememberRect;
+    QButtonGroup *mPrintKeyActionGroup;
+    QRadioButton *mRememberAlways;
+    QRadioButton *mRememberUntilClosed;
+    QCheckBox *mCopyImageToClipboard;
+    QCheckBox *mAutoSaveImage;
     QCheckBox *mUseLightBackground;
-    QCheckBox *mCopyPathToClipboard;
+    QCheckBox *mShowMagnifier;
+    QCheckBox *mReleaseToCapture;
 };
 
 #endif // GENERALOPTIONSPAGE_H
