@@ -22,10 +22,12 @@
 
 #include "SettingsPage.h"
 
-class QDialogButtonBox;
 class QLineEdit;
 class QComboBox;
 class KUrlRequester;
+class QCheckBox;
+class QSlider;
+class QLabel;
 
 class SaveOptionsPage : public SettingsPage
 {
@@ -33,23 +35,27 @@ class SaveOptionsPage : public SettingsPage
 
     public:
 
-    explicit SaveOptionsPage(QWidget *parent = 0);
+    explicit SaveOptionsPage(QWidget *parent = nullptr);
 
-    public slots:
+    public Q_SLOTS:
 
-    void saveChanges() Q_DECL_OVERRIDE;
-    void resetChanges() Q_DECL_OVERRIDE;
+    void saveChanges() override;
+    void resetChanges() override;
 
-    private slots:
+    private Q_SLOTS:
 
-    void markDirty(const QString &text);
+    void markDirty();
 
     private:
 
-    QDialogButtonBox *mDialogButtonBox;
+    void updateFilenamePreview();
+
     QLineEdit        *mSaveNameFormat;
     KUrlRequester    *mUrlRequester;
     QComboBox        *mSaveImageFormat;
+    QCheckBox        *mCopyPathToClipboard;
+    QSlider          *mQualitySlider;
+    QLabel           *mPreviewLabel;
 };
 
 #endif // SAVEOPTIONSPAGE_H
