@@ -28,10 +28,10 @@ class SettingsPage : public QWidget
 
     public:
 
-    explicit SettingsPage(QWidget *parent = 0);
+    explicit SettingsPage(QWidget *parent = nullptr);
     virtual ~SettingsPage();
 
-    public slots:
+    public Q_SLOTS:
 
     virtual void saveChanges() = 0;
     virtual void resetChanges() = 0;
